@@ -1,6 +1,7 @@
-from .model_location import ModelLocation
 from .refresh_schedule import RefreshSchedule
+from .model_location import ModelLocation
 from .model_version import ModelVersion
+import time
 
 
 class Model():
@@ -31,7 +32,7 @@ class Model():
         return self.__class__ == other.__class__ and self.id == other.id
 
     def to_dict(self):
-        return {'name': self.name, 'model_id': self.model_id, 'model_config': self.model_config, 'created_at': self.created_at, 'project_id': self.project_id, 'shared': self.shared, 'shared_at': self.shared_at, 'location': [elem.to_dict() for elem in self.location or []], 'refresh_schedules': self.refresh_schedules.to_dict() if self.refresh_schedules else None, 'latest_model_version': [elem.to_dict() for elem in self.latest_model_version or []]}
+        return {'name': self.name, 'model_id': self.model_id, 'model_config': self.model_config, 'created_at': self.created_at, 'project_id': self.project_id, 'shared': self.shared, 'shared_at': self.shared_at, 'location': self.location.to_dict() if self.location else None, 'refresh_schedules': self.refresh_schedules.to_dict() if self.refresh_schedules else None, 'latest_model_version': [elem.to_dict() for elem in self.latest_model_version or []]}
 
     def refresh(self):
         self.__dict__.update(self.describe().__dict__)
@@ -61,9 +62,6 @@ class Model():
     def delete(self):
         return self.client.delete_model(self.model_id)
 
-    def create_deployment(self, name=None, description=None, calls_per_second=None, auto_deploy=True):
-        return self.client.create_deployment(self.model_id, name, description, calls_per_second, auto_deploy)
-
     def wait_for_training(self, timeout=None):
         return self.client._poll(self, {'PENDING', 'TRAINING'}, delay=30, timeout=timeout)
 
@@ -71,7 +69,16 @@ class Model():
         return self.wait_for_training()
 
     def wait_for_full_automl(self, timeout=None):
-        return self.client._poll(self, {'PENDING', 'TRAINING'}, delay=30, timeout=timeout, poll_args={'get_automl_status': True})
+        start_time = time.time()
+        while True:
+            if timeout and time.time() - start_time > timeout:
+                raise TimeoutError(f'Maximum wait time of {timeout}s exceeded')
+            model_version = self.client._call_api('describeModel', 'GET', query_params={
+                                                  'modelId': self.model_id, 'waitForFullAutoml': True}, parse_type=Model).latest_model_version
+            if model_version.status not in {'PENDING', 'TRAINING'} and not model_version.pending_deployment_ids:
+                break
+            time.sleep(30)
+        return self.describe()
 
     def get_status(self, get_automl_status: bool = False):
         if get_automl_status:
